@@ -8,7 +8,9 @@ mostly wrapper code around Native Wifi wlanapi.h
 """
 
 import contextlib
+import logging
 import sys
+import threading
 from ctypes import (
     c_bool,
     c_byte,
@@ -23,6 +25,7 @@ from ctypes import (
     c_wchar,
 )
 from enum import Enum
+from subprocess import SubprocessError, check_output
 
 from .guid import GUID
 
@@ -57,6 +60,7 @@ class SystemErrorCodes(Enum):
     ERROR_NOT_SUPPORTED = 50
     ERROR_SERVICE_NOT_ACTIVE = 1062
     ERROR_NOT_FOUND = 1168
+    ERROR_REMOTE_SESSION_LIMIT_EXCEEDED = 1220
     ERROR_NDIS_DOT11_POWER_STATE_INVALID = 0x80342002
     ERROR_INVALID_STATE = 5023
 
@@ -86,7 +90,7 @@ WLAN_API_EXISTS = True
 # load wlanapi.dll into memory
 try:
     WLAN_API = windll.LoadLibrary("wlanapi.dll")
-except OSError as error:
+except OSError:
     WLAN_API_EXISTS = False
     print("!!! wlanapi.dll not foud !!!")
 
@@ -887,11 +891,37 @@ class WirelessInterface(object):
     """Data class for the wireless interface"""
 
     def __init__(self, wlan_iface_info):
+        self.log = logging.getLogger(__name__)
         self.description = wlan_iface_info.strInterfaceDescription
         self.guid = GUID(wlan_iface_info.InterfaceGuid)
         self.guid_string = str(wlan_iface_info.InterfaceGuid)
         self.state = wlan_iface_info.isState
         self.state_string = WLAN_INTERFACE_STATE_DICT.get(self.state, 0)
+        self.map_guid_to_mac_and_connection_name(self.guid, self.description)
+
+    def map_guid_to_mac_and_connection_name(self, guid, description) -> None:
+        guid = str(guid)[1:-1]  # remove { } around guid
+        exe = 'getmac.exe /FO "CSV" /V'  # use getmac.exe to map interface guid to mac
+        cmd = f"{exe}"
+        try:
+            output = check_output(cmd)
+            mac = ""
+            self.log.debug(
+                "checking output from '%s' to do a lookup on given guid for matching MAC and connection name",
+                exe,
+            )
+            for line in output.decode().splitlines():
+                if guid in line or description in line:
+                    connection = line.split(",")
+                    mac = connection[2].replace('"', "")
+                    self.mac = mac.lower().replace("-", ":")
+                    self.connection_name = connection[0].replace('"', "")
+                    self.log.debug(
+                        f"guid {guid} maps to {self.mac} and {self.connection_name}"
+                    )
+                    break
+        except SubprocessError as error:
+            print(error)
 
     def __str__(self):
         return f"Interface: {self.__dict__}"
@@ -932,7 +962,6 @@ typedef enum _WLAN_NOTIFICATION_ACM {
   v1_enum
 } WLAN_NOTIFICATION_ACM, *PWLAN_NOTIFICATION_ACM;
 """
-WLAN_NOTIFICATION_SOURCE_ACM = c_uint
 WLAN_NOTIFICATION_SOURCE_ACM_DICT = {
     0x00000001: "Autoconfig_Enabled",
     0x00000002: "Autoconfig_Disabled",
@@ -1504,6 +1533,7 @@ class WLAN:
         handle = WLAN.open_handle()
         result = WLAN.wlan_scan(handle, guid)
         if result is not SystemErrorCodes.ERROR_SUCCESS.value:
+            WLAN.close_handle(handle)
             raise Exception(f"wlan scan() failed: {SystemErrorCodes(result)}:{result}")
         WLAN.close_handle(handle)
 
@@ -1525,7 +1555,7 @@ class WLAN:
             data = ssid
             dot11_ssid = byref(DOT11SSID(length, data))
         else:
-            dot11_ssid = None
+            dot11_ssid = None  # type: ignore
         result = func_ref(client_handle, byref(interface_guid), dot11_ssid, None, None)
         if result is not SystemErrorCodes.ERROR_SUCCESS.value:
             raise WLANScanError(
@@ -1534,25 +1564,49 @@ class WLAN:
         return result
 
     @staticmethod
-    def get_wireless_interfaces() -> list:
+    def get_wireless_interfaces() -> dict:
         """Returns a list of WirelessInterface objects based on the wireless
         interfaces available.
         """
-        out_list = []
-        handle = WLAN.open_handle()
+        ifaces = {}
         try:
+            threads = list()
+            handle = WLAN.open_handle()
             wlan_interfaces = WLAN.enumerate_interfaces(handle)
             data_type = wlan_interfaces.contents.InterfaceInfo._type_
             num = wlan_interfaces.contents.NumberOfItems
             ifaces_pointer = addressof(wlan_interfaces.contents.InterfaceInfo)
             wlan_interface_info_list = (data_type * num).from_address(ifaces_pointer)
-            for info in wlan_interface_info_list:
-                wlan_iface = WirelessInterface(info)
-                out_list.append(wlan_iface)
+
+            def WirelessInterfaceThread(index, info):
+                ifaces[index] = WirelessInterface(info)
+
+            for index, info in enumerate(wlan_interface_info_list):
+                t = threading.Thread(
+                    target=WirelessInterfaceThread,
+                    args=(
+                        index,
+                        info,
+                    ),
+                )
+                t.daemon = (
+                    True  # we want the thread to terminate if the main process ends
+                )
+                threads.append(t)
+                t.start()
+
+            for index, t in enumerate(threads):
+                t.join()
+
+            ifaces = {
+                k: ifaces[k] for k in sorted(ifaces)
+            }  # sort by key (index) numerically
+        except Exception:
+            raise
         finally:
             WLAN.free_memory(wlan_interfaces)
             WLAN.close_handle(handle)
-        return out_list
+        return ifaces
 
     @staticmethod
     def get_wireless_network_bss_list(interface) -> list:
